@@ -29,7 +29,7 @@ class MetaDataTypes(Enum):
     Role = '09736b02-9cac-4e3f-b4f7-d3e9576ab948'  # Роли
     Language = '9cd510ce-abfc-11d4-9434-004095e12fc7'  # Языки
     # ПараметрыСеанса = '24c43748-c938-45d0-8d14-01424a72b11e'
-    # Перечисления = "f6a80749-5ad7-400b-8519-39dc5dff2542"
+    Enums = "f6a80749-5ad7-400b-8519-39dc5dff2542"  # Перечисления
     # ПланВидовХарактеристик = '82a1b659-b220-4d94-a9bd-14d757b95a48'
     # ПланыВидовРасчета = '30b100d6-b29f-47ac-aec7-cb8ca8a54767'
     # ПланыОбмена = '857c4a91-e5f4-4fac-86ec-787626f1c108'
@@ -38,7 +38,7 @@ class MetaDataTypes(Enum):
     # РегистрыРасчета = 'f2de87a8-64e5-45eb-a22d-b3aedab050e7'
     # Стили = '3e5404af-6ef8-4c73-ad11-91bd2dfac4c8'
     # РегистрыБухгалтерии = '2deed9b8-0056-4ffe-a473-c20a6c32a0bc'
-    # ЭлеменыСтиля = '58848766-36ea-4076-8800-e91eb49590d7'
+    StyleItems = '58848766-36ea-4076-8800-e91eb49590d7'  # ЭлеменыСтиля
     # HTTPСервисы = '0fffc09c-8f4c-47cc-b41c-8d5c5a221d79'
     # XDTOПакеты = 'cc9df798-7c94-4616-97d2-7aa0b7bc515e'
     # WebСервисы = '8657032e-7740-4e1d-a3ba-5dd6e8afb78f'
